==> icons-vue-0.6.0.tgz: package/lib/watson-health/stacked-scrolling--2/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthStackedScrolling_216 = {
  name: 'WatsonHealthStackedScrolling_216',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M8,30H2a2,2,0,0,1-2-2V14a2,2,0,0,1,2-2H8a2,2,0,0,1,2,2V28A2,2,0,0,1,8,30ZM2,14V28H8V14Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M20,30H14a2,2,0,0,1-2-2V14a2,2,0,0,1,2-2h6a2,2,0,0,1,2,2V28A2,2,0,0,1,20,30ZM14,14V28h6V14Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M27,21H25V9H17V7h8a2,2,0,0,1,2,2Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M32,16H30V4H22V2h8a2,2,0,0,1,2,2Z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthStackedScrolling_216;

==> icons-vue-10.6.1.tgz: package/lib/watson-health/stacked-scrolling--2/16.js <==
'use strict';

var __chunk_1 = require('../../chunk-d2faeea1.js');
var iconHelpers = require('@carbon/icon-helpers');

var virtual_WatsonHealthStackedScrolling_216 = {
  name: 'WatsonHealthStackedScrolling_216',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M8 30H2a2 2 0 0 1-2-2V14a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2zM2 14v14h6V14zm18 16h-6a2 2 0 0 1-2-2V14a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2zm-6-16v14h6V14z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M27 21h-2V9h-8V7h8a2 2 0 0 1 2 2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M32 16h-2V4h-8V2h8a2 2 0 0 1 2 2z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthStackedScrolling_216;
